@@ -10,7 +10,7 @@ __all__ = ('is_isbn10', 'is_isbn13', 'clean', 'mask', 'info', 'meta',
            'NotRecognizedServiceError', 'NotValidISBNError',
            'PluginNotLoadedError')
 
-__version__ = '3.3.7'                               # <-- literal IDs
+__version__ = '3.3.8'                               # <-- literal IDs
 __support__ = 'py26, py27, py33, py34, pypy'        # <-- literal IDs
 
 import logging as _logging
@@ -27,7 +27,7 @@ except:              # pragma: no cover
         def emit(self, record):
             pass
     _nh = NullHandler()
-_logging.getLogger('isbn').addHandler(_nh)
+_logging.getLogger('isbnlib').addHandler(_nh)
 
 # configuration
 from . import config                                # <-- first import
